---
title: <span class="badge object-type-scalar"></span> KiloNewtonMeters
---
# <span class="badge object-type-scalar"></span> KiloNewtonMeters

Force: Kilonewton-meters (kNm)

## Definition

```python
# Force: Kilonewton-meters (kNm)
KiloNewtonMeters: typing.Literal["forcekNm"] = "forcekNm"
```
